@@ -31,6 +31,7 @@ w_*
 replace
 *ttf
 fonts
+cc
 
 # IDE 文件
 .idea
@@ -44,6 +45,7 @@ go.sum
 *.exe
 
 # Python 相关
+venv
 __pycache__
 build
 dist
@@ -62,7 +64,10 @@ logs
 
 # 存储文件
 uploads
+storage
 *.db
+testdata
+_gsdata_
 
 # Dropbox
 *.paper
